pub struct MultiLanguageTSVRecord {
pub key: String,
pub translations: HashMap<String, String>,
}Expand description
Represents a multi-language TSV record where the first column is the key and subsequent columns are translations for different languages.
Fields
key: Stringtranslations: HashMap<String, String>Implementations
Sourceimpl MultiLanguageTSVRecord
impl MultiLanguageTSVRecord
Sourcepub fn add_translation(&mut self, language: String, value: String)
pub fn add_translation(&mut self, language: String, value: String)
Adds a translation for a specific language.
Sourcepub fn get_translation(&self, language: &str) -> Option<&String>
pub fn get_translation(&self, language: &str) -> Option<&String>
Gets a translation for a specific language.